@@ -498,7 +498,7 @@ main(int argc,char *argv[])
     result=asn1_parser2tree("pkix.asn",&PKIX1Implicit88,errorDescription);
 
   if(result != ASN1_SUCCESS){
-    libasn1_perror(result);
+    libtasn1_perror(result);
     printf("%s",errorDescription);
     exit(1);
   }
